From 7c6156f7269e4756d1be2e073c97ca16deddb67f Mon Sep 17 00:00:00 2001
From: hallc-online <hallc-online@jlab.org>
Date: Wed, 8 Mar 2017 11:40:52 -0500
Subject: [PATCH] Calibrated SHMS DCs.

The calibration scripts work in a very specific way. First you have to change the
`wire_drift_times.h` to read the correct run. Then you have to change the
`pdc_plane_time_zero` in the parameter file to `1280`, since it is hardcoded.
Then you replay the run with these values and run the calibration. Then you
get the correct corrections to the time zero.
---
 .../scripts/get_pdc_time_histo.C              |  15 +-
 .../get_pdc_time_histo_tzero_corrected.C      |   2 +-
 .../shms_dc_calib/scripts/input_RUN.txt       |   2 +-
 .../shms_dc_calib/scripts/wire_drift_times.h  |   6 +-
 DEF-files/SHMS/GEN/pstackana.def              |  28 +-
 PARAM/SHMS/DC/pdc_tracking.param              |   7 +-
 PARAM/SHMS/DC/pdriftmap.param                 | 316 +++++++++---------
 7 files changed, 184 insertions(+), 192 deletions(-)

diff --git a/CALIBRATION/shms_dc_calib/scripts/get_pdc_time_histo.C b/CALIBRATION/shms_dc_calib/scripts/get_pdc_time_histo.C
index ddb74ae6..87669b2b 100644
--- a/CALIBRATION/shms_dc_calib/scripts/get_pdc_time_histo.C
+++ b/CALIBRATION/shms_dc_calib/scripts/get_pdc_time_histo.C
@@ -12,9 +12,11 @@ void get_pdc_time_histo()
   ifstream infile(f0);
   infile >> run_NUM;
 
+  TString file_name = "../../../ROOTfiles/shms_replay_%d.root";
+
   //Create RUN Directories if they dont exist
-  char *dir0 = Form("mkdir ../root_files/run%d", run_NUM);
-  char *dir1 = Form("mkdir ../data_files/run%d", run_NUM);
+  char *dir0 = Form("mkdir -p ../root_files/run%d", run_NUM);
+  char *dir1 = Form("mkdir -p ../data_files/run%d", run_NUM);
 
   if (system(dir0 || dir1) != 0) {
     system(dir0);
@@ -22,7 +24,7 @@ void get_pdc_time_histo()
   }
 
   //open file
-  TFile *f = new TFile(Form("../../../ROOTfiles/pdc_replay_%d.root", run_NUM), "READ");
+  TFile *f = new TFile(Form(file_name.Data(), run_NUM), "READ");
 
   //create new file
   TFile *g = new TFile(Form("../root_files/run%d/shms_dc_time_%d.root", run_NUM, run_NUM), "RECREATE"); // create new file to store histo
@@ -63,7 +65,6 @@ void get_pdc_time_histo()
     h[ip] = new TH1F(drift_time_histo, title, 200, -50, 350);  //set time to 400 ns/200 bins = 2ns/bin
   }
  
-
  
   //Declare number of entries in the tree
   Long64_t nentries = tree->GetEntries(); //number of triggers (particles that passed through all 4 hodo planes)
@@ -87,12 +88,6 @@ void get_pdc_time_histo()
 
     }
 
-
-
-		
   //Write histograms to file
   g->Write();
-
-
-
 }
diff --git a/CALIBRATION/shms_dc_calib/scripts/get_pdc_time_histo_tzero_corrected.C b/CALIBRATION/shms_dc_calib/scripts/get_pdc_time_histo_tzero_corrected.C
index 581f7972..fa028104 100644
--- a/CALIBRATION/shms_dc_calib/scripts/get_pdc_time_histo_tzero_corrected.C
+++ b/CALIBRATION/shms_dc_calib/scripts/get_pdc_time_histo_tzero_corrected.C
@@ -16,7 +16,7 @@ void get_pdc_time_histo_tzero_corrected()
 
 
 	  //open file
-	  TFile *f = new TFile(Form("../../../ROOTfiles/pdc_replay_%d.root", run_NUM), "READ");
+	  TFile *f = new TFile(Form("../../../ROOTfiles/shms_replay_%d.root", run_NUM), "READ");
 
 	  //updates file
 	  TFile *g = new TFile(Form("../root_files/run%d/shms_dc_t0_corrected_%d.root", run_NUM, run_NUM), "UPDATE"); // create new file to store histo
diff --git a/CALIBRATION/shms_dc_calib/scripts/input_RUN.txt b/CALIBRATION/shms_dc_calib/scripts/input_RUN.txt
index 74fa38c9..ce9cd490 100644
--- a/CALIBRATION/shms_dc_calib/scripts/input_RUN.txt
+++ b/CALIBRATION/shms_dc_calib/scripts/input_RUN.txt
@@ -1 +1 @@
-407
+437
diff --git a/DEF-files/SHMS/GEN/pstackana.def b/DEF-files/SHMS/GEN/pstackana.def
index 0609baf9..c330a2c2 100644
--- a/DEF-files/SHMS/GEN/pstackana.def
+++ b/DEF-files/SHMS/GEN/pstackana.def
@@ -42,19 +42,19 @@ TH1F pdc2x1_wirenum 'SHMS DC 2X1 Wiremap; Wire Number; Number of Entries' P.dc.2
 TH1F pdc2u2_wirenum 'SHMS DC 2U2 Wiremap; Wire Number; Number of Entries' P.dc.2u2.wirenum 107 0.5 107.5
 TH1F pdc2u1_wirenum 'SHMS DC 2U1 Wiremap; Wire Number; Number of Entries' P.dc.2u1.wirenum 107 0.5 107.5
 
-TH2F pdc1u1_wirenum_vs_tdc 'SHMS DC 1U1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1u1.wirenum P.dc.1u1.time 107 0.5 107.5 500 0 500
-TH2F pdc1u2_wirenum_vs_tdc 'SHMS DC 1U2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1u2.wirenum P.dc.1u2.time 107 0.5 107.5 500 0 500
-TH2F pdc1x1_wirenum_vs_tdc 'SHMS DC 1X1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1x1.wirenum P.dc.1x1.time  79 0.5  79.5 500 0 500
-TH2F pdc1x2_wirenum_vs_tdc 'SHMS DC 1X2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1x2.wirenum P.dc.1x2.time  79 0.5  79.5 500 0 500
-TH2F pdc1v1_wirenum_vs_tdc 'SHMS DC 1V1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1v1.wirenum P.dc.1v1.time 107 0.5 107.5 500 0 500
-TH2F pdc1v2_wirenum_vs_tdc 'SHMS DC 1V2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1v2.wirenum P.dc.1v2.time 107 0.5 107.5 500 0 500
-
-TH2F pdc2v2_wirenum_vs_tdc 'SHMS DC 2V2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2v2.wirenum P.dc.2v2.time 107 0.5 107.5 500 0 500
-TH2F pdc2v1_wirenum_vs_tdc 'SHMS DC 2V1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2v1.wirenum P.dc.2v1.time 107 0.5 107.5 500 0 500
-TH2F pdc2x2_wirenum_vs_tdc 'SHMS DC 2X2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2x2.wirenum P.dc.2x2.time  79 0.5  79.5 500 0 500
-TH2F pdc2x1_wirenum_vs_tdc 'SHMS DC 2X1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2x1.wirenum P.dc.2x1.time  79 0.5  79.5 500 0 500
-TH2F pdc2u2_wirenum_vs_tdc 'SHMS DC 2U2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2u2.wirenum P.dc.2u2.time 107 0.5 107.5 500 0 500
-TH2F pdc2u1_wirenum_vs_tdc 'SHMS DC 2U1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2u1.wirenum P.dc.2u1.time 107 0.5 107.5 500 0 500
+TH2F pdc1u1_wirenum_vs_tdc 'SHMS DC 1U1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1u1.wirenum P.dc.1u1.time 107 0.5 107.5 600 -100 500
+TH2F pdc1u2_wirenum_vs_tdc 'SHMS DC 1U2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1u2.wirenum P.dc.1u2.time 107 0.5 107.5 600 -100 500
+TH2F pdc1x1_wirenum_vs_tdc 'SHMS DC 1X1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1x1.wirenum P.dc.1x1.time  79 0.5  79.5 600 -100 500
+TH2F pdc1x2_wirenum_vs_tdc 'SHMS DC 1X2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1x2.wirenum P.dc.1x2.time  79 0.5  79.5 600 -100 500
+TH2F pdc1v1_wirenum_vs_tdc 'SHMS DC 1V1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1v1.wirenum P.dc.1v1.time 107 0.5 107.5 600 -100 500
+TH2F pdc1v2_wirenum_vs_tdc 'SHMS DC 1V2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.1v2.wirenum P.dc.1v2.time 107 0.5 107.5 600 -100 500
+
+TH2F pdc2v2_wirenum_vs_tdc 'SHMS DC 2V2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2v2.wirenum P.dc.2v2.time 107 0.5 107.5 600 -100 500
+TH2F pdc2v1_wirenum_vs_tdc 'SHMS DC 2V1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2v1.wirenum P.dc.2v1.time 107 0.5 107.5 600 -100 500
+TH2F pdc2x2_wirenum_vs_tdc 'SHMS DC 2X2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2x2.wirenum P.dc.2x2.time  79 0.5  79.5 600 -100 500
+TH2F pdc2x1_wirenum_vs_tdc 'SHMS DC 2X1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2x1.wirenum P.dc.2x1.time  79 0.5  79.5 600 -100 500
+TH2F pdc2u2_wirenum_vs_tdc 'SHMS DC 2U2 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2u2.wirenum P.dc.2u2.time 107 0.5 107.5 600 -100 500
+TH2F pdc2u1_wirenum_vs_tdc 'SHMS DC 2U1 Wire Number vs. TDC; Wire Number; TDC Time (ns) / 1 ns' P.dc.2u1.wirenum P.dc.2u1.time 107 0.5 107.5 600 -100 500
 
 TH2F pdc1u1_wirenum_vs_resid 'SHMS 1U1 DC Wire Number vs. Residuals; Wire Number; Residuals (mm)' P.dc.1u1.wirenum P.dc.residual[0] 107 0.5 107.5 200 -1.0 1.0
 TH2F pdc1u2_wirenum_vs_resid 'SHMS 1U2 DC Wire Number vs. Residuals; Wire Number; Residuals (mm)' P.dc.1u2.wirenum P.dc.residual[1] 107 0.5 107.5 200 -1.0 1.0
@@ -180,4 +180,4 @@ TH1F ptrig_p2T_tdc 'SHMS p2x/p2y Coincidence TDC Time; Raw TDC Time (TDC Units);
 
 TH1F ptrig_pT1_tdc 'SHMS p1x/p1y/p2x/p2y Coincidence TDC Time (Slot 20, Channel 15); Raw TDC Time (TDC Units); Counts / 10 TDC Units;' T.shms.pT1_tdcTime 350 0 3500
 TH1F ptrig_pT2_tdc 'SHMS p1x/p1y/p2x/p2y Coincidence TDC Time (Slot 19, Channel 31); Raw TDC Time (TDC Units); Counts / 10 TDC Units;' T.shms.pT2_tdcTime 350 0 3500
-TH1F ptrig_pT3_tdc 'SHMS p1x/p1y/p2x/p2y Coincidence TDC Time (Slot 19, Channel 38); Raw TDC Time (TDC Units); Counts / 10 TDC Units;' T.shms.pT3_tdcTime 350 0 3500
\ No newline at end of file
+TH1F ptrig_pT3_tdc 'SHMS p1x/p1y/p2x/p2y Coincidence TDC Time (Slot 19, Channel 38); Raw TDC Time (TDC Units); Counts / 10 TDC Units;' T.shms.pT3_tdcTime 350 0 3500
diff --git a/PARAM/SHMS/DC/pdc_tracking.param b/PARAM/SHMS/DC/pdc_tracking.param
index 88f5a87e..13f409cb 100644
--- a/PARAM/SHMS/DC/pdc_tracking.param
+++ b/PARAM/SHMS/DC/pdc_tracking.param
@@ -14,11 +14,8 @@ pdc_tdc_max_win = 55000, 55000, 55000, 55000, 55000, 55000  ; TODO - wide limits
 pdc_tdc_time_per_channel = -0.10
 
 ; Zero time correction for each plane in ns that is added to TDC time.
-pdc_plane_time_zero = 1253.89,1252.55,1255.96,1256.28,1256.23,1255.7
-		      1256.94,1256.95,1258.05,1257.86,1257.78,1256.91
-
-;pdc_plane_time_zero = ;1280.0, 1280.0, 1280.0, 1280.0, 1280.0, 1280.0  ; TODO - fine calibration
-                      ;1280.0, 1280.0, 1280.0, 1280.0, 1280.0, 1280.0
+pdc_plane_time_zero = 1283.82, 1283.30, 1286.73, 1283.56, 1282.57, 1284.30
+                      1283.94, 1283.34, 1286.95, 1286.46, 1286.37, 1284.47
 
 ; For wire velocity corrections.
 pdc_wire_velocity = 13.0  ; TODO
diff --git a/PARAM/SHMS/DC/pdriftmap.param b/PARAM/SHMS/DC/pdriftmap.param
index 244d58f3..052b8dcc 100644
--- a/PARAM/SHMS/DC/pdriftmap.param
+++ b/PARAM/SHMS/DC/pdriftmap.param
@@ -1,175 +1,175 @@
-; Lookup Table: RUN 407
+; Lookup Table: RUN 437
 ; number of bins in Carlos's time to distance lookup table
 pdriftbins = 138
 ; number of 1st bin in Carlos's table in ns
 pdrift1stbin=0
 ; bin size in ns
 pdriftbinsz=2
-pwc1u1fract=0.0011461,0.00317,0.00690,0.01254,0.02136,0.03390,0.04699,0.06279,0.08064
-0.10011,0.12101,0.14262,0.16523,0.18736,0.20951,0.23249,0.25508,0.27840,0.30111
-0.32387,0.34627,0.36927,0.39111,0.41228,0.43466,0.45617,0.47746,0.49859,0.52043
-0.54100,0.56202,0.58257,0.60260,0.62368,0.64388,0.66305,0.68197,0.70039,0.71804
-0.73704,0.75642,0.77314,0.79058,0.80744,0.82256,0.83784,0.85186,0.86603,0.87953
-0.89139,0.90225,0.91173,0.92065,0.92786,0.93411,0.94044,0.94563,0.95107,0.95532
-0.95903,0.96274,0.96605,0.96914,0.97212,0.97449,0.97712,0.97977,0.98200,0.98393
-0.98554,0.98721,0.98912,0.99069,0.99189,0.99275,0.99358,0.99460,0.99558,0.99629
-0.99671,0.99723,0.99777,0.99819,0.99852,0.99873,0.99910,0.99927,0.99937,0.99944
-0.99960,0.99965,0.99973,0.99979,0.99979,0.99979,0.99979,0.99979,0.99979,0.99979
-0.99981,0.99981,0.99981,0.99981,0.99983,0.99985,0.99985,0.99992,0.99992,0.99994
-0.99996,0.99998,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+pwc1u1fract=0.0020958,0.00550,0.01002,0.01739,0.02577,0.03772,0.04948,0.06559,0.08364
+0.10279,0.12221,0.14307,0.16406,0.18584,0.20811,0.23051,0.25228,0.27458,0.29806
+0.31974,0.34080,0.36412,0.38678,0.40832,0.43010,0.45152,0.47421,0.49602,0.51701
+0.53846,0.56007,0.58198,0.60153,0.62259,0.64276,0.66234,0.68271,0.70063,0.72034
+0.73878,0.75744,0.77483,0.79075,0.80817,0.82274,0.83898,0.85205,0.86623,0.87825
+0.89020,0.90140,0.91057,0.92020,0.92776,0.93441,0.94158,0.94708,0.95216,0.95635
+0.96054,0.96447,0.96788,0.97099,0.97377,0.97675,0.97934,0.98120,0.98294,0.98481
+0.98654,0.98860,0.99004,0.99132,0.99230,0.99339,0.99404,0.99515,0.99584,0.99653
+0.99695,0.99745,0.99800,0.99826,0.99849,0.99882,0.99915,0.99925,0.99941,0.99954
+0.99967,0.99977,0.99980,0.99980,0.99987,0.99993,0.99993,0.99997,0.99997,0.99997
+0.99997,0.99997,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
 1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
 1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
-pwc1u2fract=0.00127,0.00331,0.00710,0.01279,0.02256,0.03456,0.05006,0.06705,0.08468
-0.10465,0.12550,0.14656,0.16814,0.19095,0.21414,0.23722,0.26019,0.28225,0.30516
-0.32754,0.34884,0.37136,0.39396,0.41634,0.43779,0.45970,0.48114,0.50241,0.52286
-0.54459,0.56438,0.58579,0.60643,0.62612,0.64580,0.66538,0.68534,0.70383,0.72271
-0.74108,0.75768,0.77482,0.79195,0.80863,0.82467,0.83996,0.85435,0.86800,0.88131
-0.89337,0.90401,0.91439,0.92318,0.92995,0.93691,0.94238,0.94845,0.95301,0.95701
-0.96034,0.96353,0.96680,0.97030,0.97292,0.97569,0.97829,0.98086,0.98271,0.98477
-0.98648,0.98809,0.98963,0.99127,0.99242,0.99342,0.99421,0.99500,0.99596,0.99648
-0.99706,0.99756,0.99815,0.99854,0.99877,0.99904,0.99933,0.99946,0.99958,0.99965
-0.99975,0.99981,0.99983,0.99985,0.99988,0.99988,0.99988,0.99990,0.99994,0.99994
-0.99994,0.99994,0.99994,0.99994,0.99996,0.99996,0.99996,0.99998,0.99998,0.99998
-0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998
-0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998
-0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,1.00000,1.00000
-pwc1x1fract=0.00084,0.00302,0.00638,0.01286,0.02102,0.03056,0.04350,0.05795,0.07448
-0.09124,0.11099,0.13155,0.15424,0.17589,0.19869,0.22138,0.24357,0.26587,0.28858
-0.31069,0.33196,0.35402,0.37527,0.39649,0.41940,0.44249,0.46441,0.48754,0.50889
-0.52922,0.55059,0.57150,0.59245,0.61297,0.63390,0.65456,0.67354,0.69325,0.71205
-0.72962,0.74613,0.76400,0.78059,0.79747,0.81339,0.82877,0.84429,0.85790,0.87070
-0.88286,0.89393,0.90427,0.91266,0.92057,0.92793,0.93423,0.93991,0.94538,0.95061
-0.95430,0.95782,0.96170,0.96483,0.96757,0.97038,0.97309,0.97571,0.97844,0.98085
-0.98291,0.98490,0.98660,0.98815,0.98987,0.99102,0.99205,0.99316,0.99392,0.99486
-0.99566,0.99635,0.99671,0.99719,0.99761,0.99788,0.99822,0.99853,0.99889,0.99908
-0.99929,0.99943,0.99954,0.99960,0.99964,0.99973,0.99981,0.99981,0.99983,0.99985
-0.99985,0.99987,0.99987,0.99990,0.99992,0.99992,0.99994,0.99994,0.99996,0.99996
-0.99996,0.99996,0.99996,0.99996,0.99996,0.99998,0.99998,0.99998,0.99998,0.99998
-0.99998,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+pwc1u2fract=0.00192,0.00536,0.01094,0.01854,0.02916,0.04075,0.05474,0.07176,0.08975
+0.11056,0.13105,0.15306,0.17436,0.19660,0.21781,0.24115,0.26408,0.28814,0.31077
+0.33350,0.35671,0.37931,0.40110,0.42399,0.44561,0.46795,0.48964,0.51143,0.53266
+0.55299,0.57546,0.59595,0.61543,0.63533,0.65579,0.67469,0.69323,0.71099,0.72852
+0.74609,0.76472,0.78174,0.79804,0.81421,0.82970,0.84343,0.85765,0.87162,0.88343
+0.89532,0.90613,0.91607,0.92412,0.93107,0.93769,0.94428,0.94883,0.95354,0.95724
+0.96110,0.96458,0.96779,0.97029,0.97312,0.97565,0.97792,0.98026,0.98266,0.98487
+0.98665,0.98851,0.98977,0.99127,0.99224,0.99308,0.99403,0.99493,0.99597,0.99643
+0.99711,0.99756,0.99786,0.99802,0.99854,0.99890,0.99919,0.99929,0.99935,0.99951
+0.99964,0.99974,0.99984,0.99987,0.99990,0.99990,0.99990,0.99990,0.99994,0.99994
+0.99994,0.99997,0.99997,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
 1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
-pwc1x2fract=0.00113,0.00332,0.00674,0.01204,0.01948,0.02970,0.04162,0.05732,0.07433
-0.09304,0.11287,0.13326,0.15491,0.17725,0.19875,0.22163,0.24386,0.26582,0.28932
-0.31162,0.33331,0.35504,0.37574,0.39772,0.42035,0.44254,0.46348,0.48571,0.50657
-0.52788,0.54900,0.56915,0.58898,0.60797,0.62806,0.64772,0.66640,0.68481,0.70302
-0.72191,0.73915,0.75566,0.77290,0.78981,0.80645,0.82221,0.83701,0.85164,0.86507
-0.87759,0.88880,0.90011,0.90951,0.91794,0.92527,0.93220,0.93832,0.94376,0.94823
-0.95195,0.95572,0.95959,0.96268,0.96606,0.96919,0.97209,0.97464,0.97714,0.97931
-0.98123,0.98368,0.98530,0.98710,0.98862,0.99021,0.99127,0.99230,0.99317,0.99418
-0.99480,0.99549,0.99616,0.99670,0.99729,0.99764,0.99810,0.99839,0.99864,0.99887
-0.99902,0.99914,0.99923,0.99931,0.99935,0.99937,0.99939,0.99939,0.99946,0.99950
-0.99956,0.99960,0.99962,0.99962,0.99971,0.99975,0.99981,0.99987,0.99992,0.99994
-0.99994,0.99996,0.99996,0.99996,0.99996,0.99996,0.99998,0.99998,0.99998,1.00000
+pwc1x1fract=0.00604,0.01330,0.02308,0.03473,0.04813,0.06361,0.08088,0.09973,0.11789
+0.13855,0.15859,0.18048,0.20144,0.22475,0.24776,0.26958,0.29143,0.31348,0.33685
+0.35851,0.37901,0.39974,0.42242,0.44375,0.46547,0.48686,0.50839,0.52964,0.55256
+0.57292,0.59316,0.61379,0.63334,0.65192,0.67226,0.69124,0.70831,0.72782,0.74680
+0.76429,0.78120,0.79787,0.81335,0.82811,0.84214,0.85650,0.87020,0.88221,0.89327
+0.90324,0.91206,0.92034,0.92787,0.93543,0.94187,0.94702,0.95111,0.95471,0.95798
+0.96200,0.96544,0.96854,0.97158,0.97402,0.97643,0.97891,0.98079,0.98257,0.98409
+0.98567,0.98739,0.98914,0.99066,0.99165,0.99294,0.99422,0.99488,0.99584,0.99640
+0.99706,0.99752,0.99799,0.99825,0.99842,0.99878,0.99891,0.99908,0.99927,0.99934
+0.99954,0.99960,0.99964,0.99967,0.99970,0.99970,0.99977,0.99987,0.99987,0.99993
+0.99993,0.99993,0.99993,0.99997,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
 1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
 1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
-pwc1v1fract=0.00077,0.00209,0.00420,0.00836,0.01424,0.02304,0.03247,0.04524,0.05917
-0.07543,0.09333,0.11271,0.13213,0.15260,0.17474,0.19765,0.22134,0.24477,0.26716
-0.28930,0.31121,0.33350,0.35621,0.37640,0.39980,0.42164,0.44341,0.46611,0.48762
-0.50962,0.53092,0.55227,0.57347,0.59253,0.61300,0.63276,0.65268,0.67194,0.69019
-0.70785,0.72589,0.74331,0.76150,0.77837,0.79604,0.81193,0.82783,0.84291,0.85715
-0.86959,0.88271,0.89336,0.90383,0.91341,0.92204,0.92955,0.93573,0.94150,0.94727
-0.95169,0.95547,0.95907,0.96274,0.96590,0.96902,0.97188,0.97468,0.97717,0.97985
-0.98183,0.98409,0.98585,0.98733,0.98877,0.99017,0.99172,0.99281,0.99400,0.99479
-0.99565,0.99634,0.99674,0.99703,0.99743,0.99778,0.99812,0.99835,0.99868,0.99902
-0.99925,0.99939,0.99950,0.99950,0.99952,0.99958,0.99962,0.99967,0.99969,0.99977
-0.99979,0.99981,0.99981,0.99983,0.99985,0.99985,0.99990,0.99990,0.99992,0.99996
-0.99996,0.99996,0.99996,0.99996,0.99996,0.99996,0.99996,0.99996,0.99996,0.99996
-0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998
-0.99998,0.99998,0.99998,0.99998,1.00000,1.00000,1.00000,1.00000,1.00000
-pwc1v2fract=0.00085,0.00249,0.00504,0.00942,0.01714,0.02640,0.03742,0.05064,0.06623
-0.08383,0.10350,0.12509,0.14709,0.16950,0.19254,0.21535,0.23741,0.26089,0.28266
-0.30557,0.32730,0.35123,0.37306,0.39461,0.41621,0.43861,0.46050,0.48284,0.50419
-0.52549,0.54701,0.56814,0.58931,0.61006,0.62997,0.64970,0.66869,0.68698,0.70574
-0.72446,0.74160,0.75891,0.77620,0.79281,0.80862,0.82413,0.83946,0.85362,0.86686
-0.87935,0.89122,0.90216,0.91127,0.92063,0.92786,0.93348,0.93913,0.94434,0.94932
-0.95380,0.95760,0.96071,0.96385,0.96725,0.97024,0.97300,0.97582,0.97835,0.98053
-0.98284,0.98443,0.98599,0.98769,0.98950,0.99074,0.99182,0.99290,0.99398,0.99446
-0.99550,0.99610,0.99682,0.99728,0.99768,0.99811,0.99836,0.99859,0.99878,0.99892
-0.99915,0.99921,0.99934,0.99946,0.99961,0.99961,0.99963,0.99975,0.99977,0.99981
-0.99985,0.99985,0.99990,0.99990,0.99992,0.99992,0.99992,0.99994,0.99994,0.99994
-0.99994,0.99996,0.99996,0.99996,0.99996,0.99996,0.99996,0.99996,0.99998,0.99998
-0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,1.00000,1.00000,1.00000
+pwc1x2fract=0.00262,0.00736,0.01364,0.02145,0.03149,0.04365,0.05850,0.07521,0.09336
+0.11409,0.13596,0.15849,0.17942,0.20123,0.22396,0.24655,0.26751,0.29037,0.31038
+0.33356,0.35491,0.37637,0.39811,0.41904,0.43843,0.45975,0.47989,0.50095,0.52302
+0.54388,0.56465,0.58508,0.60532,0.62478,0.64424,0.66343,0.68249,0.70067,0.71699
+0.73511,0.75374,0.77078,0.78834,0.80407,0.81999,0.83503,0.85050,0.86315,0.87587
+0.88771,0.89854,0.90736,0.91619,0.92384,0.93114,0.93705,0.94301,0.94804,0.95219
+0.95631,0.96014,0.96334,0.96622,0.96923,0.97201,0.97463,0.97741,0.97996,0.98182
+0.98349,0.98519,0.98699,0.98878,0.99029,0.99212,0.99313,0.99428,0.99500,0.99572
+0.99601,0.99650,0.99702,0.99745,0.99794,0.99837,0.99863,0.99879,0.99895,0.99915
+0.99922,0.99928,0.99944,0.99948,0.99957,0.99961,0.99964,0.99967,0.99967,0.99967
+0.99971,0.99974,0.99974,0.99977,0.99977,0.99980,0.99980,0.99984,0.99984,0.99984
+0.99984,0.99984,0.99987,0.99987,0.99990,0.99990,0.99990,0.99990,0.99993,0.99993
+0.99993,0.99993,0.99993,0.99993,0.99993,0.99993,0.99993,0.99993,0.99993,0.99993
+0.99993,0.99997,0.99997,0.99997,0.99997,1.00000,1.00000,1.00000,1.00000
+pwc1v1fract=0.00587,0.01226,0.02231,0.03338,0.04752,0.06370,0.08110,0.09998,0.12120
+0.14212,0.16364,0.18562,0.20819,0.23067,0.25255,0.27584,0.29838,0.31980,0.34280
+0.36468,0.38594,0.40953,0.43039,0.45280,0.47507,0.49725,0.51913,0.54075,0.56114
+0.58138,0.60115,0.62309,0.64342,0.66115,0.68069,0.69911,0.71599,0.73444,0.75210
+0.76947,0.78617,0.80225,0.81731,0.83349,0.84756,0.86078,0.87346,0.88546,0.89620
+0.90612,0.91515,0.92319,0.93021,0.93650,0.94171,0.94705,0.95087,0.95542,0.95888
+0.96326,0.96622,0.96939,0.97196,0.97443,0.97690,0.97927,0.98181,0.98359,0.98540
+0.98718,0.98890,0.99028,0.99183,0.99285,0.99433,0.99502,0.99591,0.99641,0.99700
+0.99740,0.99769,0.99806,0.99839,0.99858,0.99871,0.99895,0.99914,0.99934,0.99951
+0.99964,0.99970,0.99977,0.99984,0.99990,0.99993,0.99993,0.99993,0.99997,0.99997
+0.99997,0.99997,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
 1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
-pwc2v2fract=0.00129,0.00346,0.00736,0.01307,0.02121,0.03166,0.04446,0.06031,0.07829
-0.09779,0.11941,0.14128,0.16459,0.18914,0.21232,0.23520,0.25936,0.28268,0.30550
-0.32828,0.35158,0.37350,0.39517,0.41699,0.43893,0.46012,0.48101,0.50190,0.52294
-0.54444,0.56432,0.58482,0.60410,0.62328,0.64206,0.66127,0.67956,0.69745,0.71394
-0.73107,0.74715,0.76363,0.77922,0.79396,0.80918,0.82319,0.83655,0.84989,0.86167
-0.87272,0.88359,0.89330,0.90240,0.91032,0.91799,0.92465,0.93048,0.93568,0.94035
-0.94456,0.94831,0.95240,0.95586,0.95930,0.96235,0.96556,0.96818,0.97069,0.97295
-0.97512,0.97729,0.97930,0.98121,0.98301,0.98489,0.98651,0.98784,0.98917,0.99045
-0.99143,0.99254,0.99348,0.99422,0.99482,0.99542,0.99606,0.99657,0.99696,0.99743
-0.99776,0.99808,0.99844,0.99867,0.99883,0.99901,0.99913,0.99935,0.99948,0.99958
-0.99965,0.99969,0.99972,0.99977,0.99981,0.99982,0.99984,0.99985,0.99989,0.99991
-0.99994,0.99994,0.99994,0.99995,0.99995,0.99995,0.99998,0.99999,1.00000,1.00000
+pwc1v2fract=0.00340,0.00893,0.01651,0.02543,0.03609,0.04979,0.06568,0.08337,0.10194
+0.12119,0.14185,0.16438,0.18602,0.20930,0.23231,0.25553,0.27583,0.29930,0.32258
+0.34478,0.36697,0.38927,0.41196,0.43308,0.45629,0.47891,0.50062,0.52233,0.54204
+0.56355,0.58389,0.60442,0.62498,0.64329,0.66307,0.68370,0.70181,0.72126,0.73875
+0.75477,0.77295,0.78887,0.80365,0.81797,0.83297,0.84749,0.86158,0.87485,0.88610
+0.89646,0.90617,0.91467,0.92334,0.93059,0.93674,0.94217,0.94733,0.95158,0.95606
+0.96021,0.96325,0.96587,0.96920,0.97208,0.97496,0.97754,0.97963,0.98179,0.98382
+0.98532,0.98686,0.98885,0.99019,0.99114,0.99222,0.99304,0.99405,0.99487,0.99552
+0.99637,0.99696,0.99722,0.99761,0.99804,0.99830,0.99859,0.99879,0.99886,0.99905
+0.99922,0.99938,0.99944,0.99957,0.99964,0.99967,0.99971,0.99974,0.99974,0.99977
+0.99977,0.99980,0.99984,0.99984,0.99984,0.99984,0.99984,0.99984,0.99984,0.99984
+0.99984,0.99984,0.99984,0.99987,0.99987,0.99987,0.99987,0.99987,0.99987,0.99987
+0.99987,0.99987,0.99987,0.99987,0.99987,0.99987,0.99987,0.99987,0.99987,0.99987
+0.99990,0.99990,0.99993,0.99997,0.99997,0.99997,1.00000,1.00000,1.00000
+pwc2v2fract=0.00355,0.00811,0.01463,0.02407,0.03587,0.04919,0.06677,0.08541,0.10400
+0.12540,0.14794,0.17011,0.19288,0.21693,0.23949,0.26299,0.28650,0.30951,0.33287
+0.35488,0.37780,0.39963,0.42181,0.44353,0.46490,0.48629,0.50656,0.52717,0.54784
+0.56852,0.58965,0.60916,0.62797,0.64653,0.66474,0.68310,0.70099,0.71828,0.73546
+0.75155,0.76685,0.78194,0.79734,0.81166,0.82645,0.83962,0.85270,0.86479,0.87595
+0.88651,0.89623,0.90495,0.91333,0.92068,0.92721,0.93332,0.93810,0.94279,0.94743
+0.95203,0.95604,0.95939,0.96229,0.96514,0.96786,0.97076,0.97319,0.97559,0.97771
+0.97986,0.98193,0.98360,0.98553,0.98730,0.98893,0.99021,0.99108,0.99205,0.99300
+0.99375,0.99470,0.99540,0.99585,0.99629,0.99679,0.99719,0.99765,0.99799,0.99832
+0.99846,0.99862,0.99894,0.99903,0.99914,0.99923,0.99937,0.99953,0.99964,0.99968
+0.99975,0.99982,0.99982,0.99984,0.99987,0.99987,0.99991,0.99993,0.99995,0.99996
+0.99996,0.99996,0.99996,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998
+0.99998,0.99998,0.99998,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+pwc2v1fract=0.00372,0.00848,0.01548,0.02441,0.03573,0.04956,0.06476,0.08295,0.10351
+0.12426,0.14625,0.16946,0.19199,0.21540,0.23858,0.26192,0.28639,0.30861,0.33119
+0.35334,0.37566,0.39810,0.42021,0.44146,0.46266,0.48382,0.50582,0.52804,0.54885
+0.56798,0.58801,0.60859,0.62777,0.64688,0.66520,0.68353,0.70152,0.71956,0.73761
+0.75335,0.76982,0.78458,0.79995,0.81450,0.82748,0.84073,0.85341,0.86489,0.87527
+0.88573,0.89487,0.90394,0.91159,0.91911,0.92546,0.93130,0.93661,0.94148,0.94587
+0.94992,0.95404,0.95789,0.96136,0.96449,0.96755,0.97010,0.97255,0.97491,0.97713
+0.97915,0.98114,0.98275,0.98458,0.98592,0.98751,0.98881,0.99004,0.99134,0.99221
+0.99298,0.99396,0.99456,0.99526,0.99597,0.99640,0.99714,0.99754,0.99778,0.99816
+0.99841,0.99861,0.99882,0.99897,0.99915,0.99920,0.99937,0.99944,0.99953,0.99964
+0.99971,0.99976,0.99978,0.99982,0.99986,0.99986,0.99989,0.99996,0.99998,0.99998
+1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
 1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
 1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
-pwc2v1fract=0.00151,0.00409,0.00751,0.01309,0.02108,0.03163,0.04409,0.05983,0.07802
-0.09868,0.11948,0.14150,0.16342,0.18636,0.20996,0.23344,0.25601,0.28046,0.30303
-0.32570,0.34779,0.36990,0.39226,0.41446,0.43568,0.45718,0.47814,0.49937,0.52082
-0.54142,0.56148,0.58173,0.60162,0.62151,0.64079,0.65960,0.67791,0.69506,0.71241
-0.72987,0.74655,0.76276,0.77851,0.79359,0.80854,0.82258,0.83580,0.84910,0.86151
-0.87331,0.88440,0.89438,0.90303,0.91114,0.91866,0.92503,0.93099,0.93689,0.94189
-0.94638,0.95009,0.95404,0.95767,0.96100,0.96421,0.96683,0.96938,0.97196,0.97453
-0.97684,0.97904,0.98105,0.98310,0.98485,0.98650,0.98813,0.98936,0.99054,0.99159
-0.99262,0.99344,0.99418,0.99473,0.99535,0.99589,0.99649,0.99690,0.99736,0.99770
-0.99805,0.99841,0.99862,0.99887,0.99910,0.99922,0.99937,0.99946,0.99955,0.99960
-0.99968,0.99974,0.99982,0.99983,0.99985,0.99988,0.99991,0.99993,0.99994,0.99995
-0.99995,0.99995,0.99995,0.99995,0.99995,0.99995,0.99997,0.99998,0.99998,0.99998
-0.99998,0.99998,0.99998,0.99999,0.99999,0.99999,0.99999,1.00000,1.00000,1.00000
+pwc2x2fract=0.00273,0.00715,0.01355,0.02204,0.03274,0.04612,0.06183,0.08042,0.09892
+0.11876,0.14088,0.16295,0.18590,0.20896,0.23253,0.25474,0.27887,0.30140,0.32319
+0.34527,0.36878,0.39027,0.41159,0.43320,0.45397,0.47620,0.49685,0.51873,0.53997
+0.56079,0.58000,0.59982,0.61994,0.63833,0.65730,0.67629,0.69488,0.71185,0.72945
+0.74559,0.76034,0.77572,0.79084,0.80480,0.81885,0.83163,0.84497,0.85717,0.86887
+0.87936,0.88973,0.89888,0.90758,0.91469,0.92266,0.92871,0.93477,0.93975,0.94473
+0.94887,0.95311,0.95691,0.96043,0.96402,0.96686,0.96950,0.97235,0.97469,0.97770
+0.97983,0.98189,0.98345,0.98514,0.98657,0.98803,0.98942,0.99069,0.99178,0.99271
+0.99365,0.99440,0.99512,0.99586,0.99630,0.99685,0.99718,0.99764,0.99805,0.99826
+0.99845,0.99870,0.99887,0.99896,0.99908,0.99926,0.99944,0.99954,0.99958,0.99961
+0.99968,0.99974,0.99974,0.99975,0.99982,0.99982,0.99984,0.99986,0.99989,0.99991
+0.99993,0.99993,0.99995,0.99995,0.99996,0.99996,0.99996,0.99996,0.99996,0.99996
+0.99996,0.99996,0.99996,0.99996,0.99996,0.99996,0.99996,0.99996,1.00000,1.00000
 1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
-pwc2x2fract=0.00106,0.00308,0.00661,0.01240,0.02065,0.03143,0.04496,0.06075,0.07973
-0.09960,0.12036,0.14274,0.16459,0.18694,0.21036,0.23369,0.25669,0.27982,0.30305
-0.32566,0.34828,0.37059,0.39291,0.41481,0.43674,0.45780,0.47902,0.49957,0.52029
-0.54063,0.56150,0.58144,0.60200,0.62122,0.64008,0.65844,0.67652,0.69464,0.71179
-0.72867,0.74540,0.76121,0.77709,0.79198,0.80619,0.81972,0.83381,0.84712,0.85866
-0.86992,0.88061,0.89113,0.90060,0.90905,0.91682,0.92346,0.92920,0.93469,0.93947
-0.94421,0.94841,0.95255,0.95586,0.95923,0.96257,0.96544,0.96849,0.97123,0.97391
-0.97604,0.97848,0.98086,0.98271,0.98429,0.98590,0.98738,0.98881,0.99006,0.99116
-0.99213,0.99328,0.99398,0.99453,0.99526,0.99573,0.99636,0.99692,0.99743,0.99779
-0.99818,0.99841,0.99873,0.99889,0.99903,0.99915,0.99938,0.99947,0.99955,0.99961
-0.99964,0.99970,0.99973,0.99976,0.99982,0.99990,0.99992,0.99993,0.99994,0.99994
-0.99994,0.99994,0.99997,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998
-0.99999,0.99999,0.99999,0.99999,0.99999,0.99999,0.99999,0.99999,0.99999,0.99999
-0.99999,0.99999,0.99999,0.99999,0.99999,1.00000,1.00000,1.00000,1.00000
-pwc2x1fract=0.00116,0.00370,0.00754,0.01342,0.02193,0.03240,0.04531,0.06106,0.07885
-0.09810,0.11859,0.13933,0.16093,0.18304,0.20545,0.22803,0.25136,0.27275,0.29579
-0.31763,0.34016,0.36200,0.38434,0.40605,0.42779,0.44961,0.47077,0.49155,0.51315
-0.53547,0.55559,0.57546,0.59568,0.61585,0.63443,0.65431,0.67326,0.69175,0.70880
-0.72585,0.74264,0.75896,0.77535,0.79110,0.80641,0.82056,0.83491,0.84831,0.86070
-0.87282,0.88359,0.89290,0.90199,0.91032,0.91777,0.92420,0.93055,0.93612,0.94105
-0.94526,0.94999,0.95374,0.95733,0.96066,0.96390,0.96680,0.96993,0.97240,0.97496
-0.97703,0.97921,0.98124,0.98325,0.98528,0.98690,0.98840,0.98980,0.99110,0.99215
-0.99321,0.99392,0.99467,0.99545,0.99595,0.99649,0.99697,0.99739,0.99769,0.99800
-0.99821,0.99849,0.99865,0.99885,0.99901,0.99916,0.99924,0.99931,0.99939,0.99949
-0.99953,0.99957,0.99962,0.99966,0.99969,0.99970,0.99973,0.99974,0.99976,0.99978
-0.99980,0.99982,0.99984,0.99985,0.99985,0.99985,0.99987,0.99987,0.99989,0.99989
-0.99989,0.99991,0.99993,0.99997,0.99998,0.99999,0.99999,1.00000,1.00000,1.00000
+pwc2x1fract=0.00269,0.00655,0.01238,0.02026,0.03076,0.04237,0.05721,0.07286,0.09074
+0.10990,0.13086,0.15127,0.17513,0.19808,0.21996,0.24259,0.26537,0.28700,0.30956
+0.33140,0.35472,0.37650,0.39789,0.41888,0.44103,0.46255,0.48301,0.50454,0.52595
+0.54652,0.56800,0.58817,0.60742,0.62763,0.64721,0.66513,0.68315,0.70174,0.71896
+0.73531,0.75199,0.76820,0.78380,0.79914,0.81382,0.82846,0.84117,0.85393,0.86529
+0.87711,0.88755,0.89691,0.90553,0.91347,0.92066,0.92770,0.93366,0.93864,0.94362
+0.94777,0.95195,0.95612,0.95964,0.96283,0.96603,0.96896,0.97175,0.97480,0.97722
+0.97963,0.98193,0.98357,0.98535,0.98699,0.98833,0.98957,0.99091,0.99207,0.99304
+0.99378,0.99456,0.99544,0.99616,0.99677,0.99721,0.99761,0.99778,0.99812,0.99846
+0.99870,0.99892,0.99919,0.99937,0.99951,0.99959,0.99971,0.99971,0.99976,0.99976
+0.99978,0.99978,0.99983,0.99985,0.99988,0.99990,0.99990,0.99992,0.99992,0.99992
+0.99992,0.99992,0.99992,0.99993,0.99995,0.99995,0.99995,0.99995,0.99995,0.99995
+0.99995,0.99995,0.99997,0.99998,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
 1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
-pwc2u2fract=0.00104,0.00279,0.00627,0.01174,0.01933,0.03030,0.04376,0.05926,0.07656
-0.09536,0.11612,0.13794,0.15975,0.18226,0.20448,0.22720,0.24993,0.27299,0.29525
-0.31742,0.33957,0.36299,0.38580,0.40726,0.42998,0.45127,0.47292,0.49455,0.51656
-0.53732,0.55858,0.58008,0.60046,0.62093,0.63978,0.65816,0.67704,0.69550,0.71338
-0.73108,0.74871,0.76498,0.78141,0.79789,0.81301,0.82768,0.84136,0.85465,0.86717
-0.87844,0.88989,0.89978,0.90818,0.91610,0.92269,0.92928,0.93495,0.94002,0.94474
-0.94915,0.95299,0.95700,0.96077,0.96398,0.96708,0.96979,0.97241,0.97466,0.97728
-0.97936,0.98165,0.98355,0.98522,0.98675,0.98816,0.98969,0.99081,0.99175,0.99283
-0.99369,0.99449,0.99534,0.99599,0.99661,0.99716,0.99758,0.99790,0.99828,0.99856
-0.99870,0.99899,0.99917,0.99926,0.99945,0.99952,0.99956,0.99963,0.99970,0.99972
-0.99978,0.99981,0.99982,0.99986,0.99990,0.99990,0.99992,0.99992,0.99992,0.99993
-0.99994,0.99994,0.99994,0.99996,0.99996,0.99996,0.99997,0.99997,0.99997,0.99997
-0.99997,0.99997,0.99997,0.99998,0.99999,0.99999,1.00000,1.00000,1.00000,1.00000
+pwc2u2fract=0.00237,0.00581,0.01068,0.01782,0.02712,0.03875,0.05280,0.06868,0.08541
+0.10517,0.12528,0.14629,0.16884,0.19099,0.21299,0.23643,0.25869,0.28213,0.30434
+0.32678,0.34909,0.37174,0.39436,0.41625,0.43794,0.45954,0.48214,0.50378,0.52612
+0.54676,0.56720,0.58734,0.60833,0.62706,0.64672,0.66643,0.68381,0.70311,0.72117
+0.73876,0.75651,0.77290,0.78840,0.80271,0.81762,0.83198,0.84523,0.85838,0.87054
+0.88217,0.89223,0.90219,0.91106,0.91891,0.92627,0.93193,0.93753,0.94300,0.94747
+0.95198,0.95570,0.95922,0.96280,0.96595,0.96887,0.97174,0.97436,0.97680,0.97881
+0.98093,0.98278,0.98473,0.98631,0.98770,0.98939,0.99066,0.99200,0.99297,0.99412
+0.99487,0.99556,0.99620,0.99659,0.99711,0.99744,0.99782,0.99821,0.99859,0.99886
+0.99900,0.99919,0.99928,0.99940,0.99952,0.99955,0.99962,0.99966,0.99969,0.99978
+0.99979,0.99986,0.99986,0.99990,0.99993,0.99995,0.99995,0.99995,0.99995,0.99995
+0.99995,0.99995,0.99997,0.99997,0.99998,0.99998,1.00000,1.00000,1.00000,1.00000
+1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
+pwc2u1fract=0.00286,0.00678,0.01311,0.02071,0.03000,0.04184,0.05560,0.07218,0.08949
+0.10886,0.12878,0.15013,0.17143,0.19400,0.21638,0.23885,0.26210,0.28499,0.30799
+0.33149,0.35450,0.37694,0.39903,0.42079,0.44323,0.46431,0.48507,0.50695,0.52818
+0.54926,0.57110,0.59212,0.61239,0.63161,0.65112,0.67003,0.68866,0.70782,0.72560
+0.74401,0.76115,0.77812,0.79482,0.80987,0.82598,0.84019,0.85395,0.86640,0.87848
+0.88970,0.89967,0.90845,0.91686,0.92449,0.93102,0.93708,0.94241,0.94746,0.95154
+0.95614,0.95993,0.96300,0.96655,0.96970,0.97251,0.97476,0.97719,0.97971,0.98181
+0.98349,0.98540,0.98741,0.98885,0.99029,0.99135,0.99259,0.99369,0.99464,0.99538
+0.99599,0.99672,0.99729,0.99767,0.99797,0.99822,0.99866,0.99885,0.99898,0.99919
+0.99929,0.99931,0.99939,0.99954,0.99958,0.99966,0.99970,0.99971,0.99975,0.99980
+0.99981,0.99983,0.99986,0.99988,0.99990,0.99992,0.99992,0.99992,0.99992,0.99992
+0.99993,0.99993,0.99995,0.99997,0.99997,0.99997,0.99997,0.99997,0.99997,1.00000
+1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
 1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000,1.00000
-pwc2u1fract=0.00099,0.00312,0.00671,0.01222,0.02005,0.03014,0.04237,0.05699,0.07340
-0.09132,0.11127,0.13169,0.15355,0.17524,0.19902,0.22079,0.24265,0.26520,0.28736
-0.30977,0.33246,0.35498,0.37819,0.40009,0.42235,0.44440,0.46651,0.48765,0.50936
-0.53129,0.55175,0.57237,0.59240,0.61234,0.63137,0.65098,0.66954,0.68778,0.70644
-0.72442,0.74206,0.75913,0.77532,0.79132,0.80682,0.82179,0.83666,0.85070,0.86396
-0.87662,0.88753,0.89781,0.90770,0.91625,0.92374,0.93025,0.93616,0.94196,0.94722
-0.95167,0.95587,0.95942,0.96276,0.96613,0.96920,0.97200,0.97453,0.97698,0.97929
-0.98148,0.98333,0.98512,0.98695,0.98858,0.99012,0.99151,0.99258,0.99359,0.99443
-0.99531,0.99605,0.99669,0.99728,0.99761,0.99793,0.99811,0.99846,0.99863,0.99883
-0.99902,0.99917,0.99924,0.99935,0.99943,0.99951,0.99957,0.99963,0.99964,0.99968
-0.99969,0.99973,0.99976,0.99978,0.99979,0.99981,0.99983,0.99983,0.99984,0.99985
-0.99986,0.99989,0.99989,0.99991,0.99992,0.99992,0.99993,0.99996,0.99996,0.99996
-0.99996,0.99996,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99998,0.99999
-0.99999,0.99999,0.99999,0.99999,1.00000,1.00000,1.00000,1.00000,1.00000
diff --git a/CALIBRATION/shms_dc_calib/scripts/wire_drift_times.h b/CALIBRATION/shms_dc_calib/scripts/wire_drift_times.h
index 862db2e5..0e6c0b22 100644
--- a/CALIBRATION/shms_dc_calib/scripts/wire_drift_times.h
+++ b/CALIBRATION/shms_dc_calib/scripts/wire_drift_times.h
@@ -2,7 +2,7 @@
 // This class has been automatically generated on
 // Tue Mar  7 17:30:40 2017 by ROOT version 5.34/36
 // from TTree T/Hall A Analyzer Output DST
 // found on file: ROOTfiles/pdc_replay_407.root
 //////////////////////////////////////////////////////////
 
 #ifndef wire_drift_times_h
@@ -324,9 +324,9 @@ wire_drift_times::wire_drift_times(TTree *tree) : fChain(0)
 // if parameter tree is not specified (or zero), connect the file
 // used to generate this class and read the Tree.
    if (tree == 0) {
-      TFile *f = (TFile*)gROOT->GetListOfFiles()->FindObject("../../../ROOTfiles/pdc_replay_407.root");
+      TFile *f = (TFile*)gROOT->GetListOfFiles()->FindObject("../../../ROOTfiles/shms_replay_437.root");
       if (!f || !f->IsOpen()) {
-         f = new TFile("../../../ROOTfiles/pdc_replay_407.root");
+         f = new TFile("../../../ROOTfiles/shms_replay_437.root");
       }
       f->GetObject("T",tree);
 
@@ -2,7 +2,7 @@
 // Tue Mar  7 17:30:40 2017 by ROOT version 5.34/36
 // from TTree T/Hall A Analyzer Output DST
-// found on file: ROOTfiles/pdc_replay_407.root
+// found on file: ROOTfiles/pdc_replay_437.root
 //////////////////////////////////////////////////////////
 
-- 
GitLab